@@ -4,7 +4,7 @@
     <message>
         <location filename="mainwindow.ui" line="14"/>
         <source>Program_Name</source>
-        <translation type="unfinished"/>
+        <translation>प्रोग्राम नाम (_N)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="46"/>
@@ -24,7 +24,7 @@
     <message>
         <location filename="mainwindow.ui" line="88"/>
         <source>Display help </source>
-        <translation>मदद देखें</translation>
+        <translation>सहायता देखें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="91"/>
@@ -39,12 +39,12 @@
     <message>
         <location filename="mainwindow.ui" line="114"/>
         <source>Back</source>
-        <translation type="unfinished"/>
+        <translation>वापस</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="172"/>
         <source>Next</source>
-        <translation type="unfinished"/>
+        <translation>आगामी</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="198"/>
@@ -66,97 +66,97 @@
         <location filename="mainwindow.cpp" line="462"/>
         <location filename="mainwindow.cpp" line="481"/>
         <source>Select ISO</source>
-        <translation type="unfinished"/>
+        <translation>आईएसओ चुनें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="250"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;लक्षित यूएसबी उपकरण चयन&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="260"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;आईएसओ फाइल चयन&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="289"/>
         <source>Advanced Options</source>
-        <translation type="unfinished"/>
+        <translation>विस्तृत विकल्प</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="307"/>
         <source>Make the ext4 filesystem even if one exists</source>
-        <translation type="unfinished"/>
+        <translation>पहले से मौजूद होने पर भी Ext4 फाइल सिस्टम बनाएँ</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="314"/>
         <source>Save the original boot directory when updating a live-usb</source>
-        <translation type="unfinished"/>
+        <translation>लाइव यूएसबी अपडेट करते समय मूल बूट डायरेक्टरी संचित करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="321"/>
         <source>Use gpt partitioning instead of msdos</source>
-        <translation type="unfinished"/>
+        <translation>MS-DOS के स्थान पर GPT विभाजन विधि उपयोग करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="324"/>
         <source>GPT partitioning</source>
-        <translation type="unfinished"/>
+        <translation>GPT विभाजन विधि</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="331"/>
         <source>Update (only update an existing live-usb)</source>
-        <translation type="unfinished"/>
+        <translation>अपडेट (केवल मौजूदा लाइव यूएसबी हेतु अपडेट)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="338"/>
         <source>Don&apos;t replace syslinux files</source>
-        <translation type="unfinished"/>
+        <translation>Syslinux फाइलें न बदलें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="341"/>
         <source>Keep syslinux files</source>
-        <translation type="unfinished"/>
+        <translation>Syslinux फाइलें रखें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="348"/>
         <source>Ignore USB/removable check</source>
-        <translation type="unfinished"/>
+        <translation>यूएसबी/हटाने योग्य उपकरण जाँच अनदेखी करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="355"/>
         <source>Temporarily disable automounting</source>
-        <translation type="unfinished"/>
+        <translation>स्वतः माउंट अस्थायी रूप से निष्क्रिय</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="365"/>
         <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
-        <translation type="unfinished"/>
+        <translation>pmbr_boot डिस्क फ्लैग सेट करें (UEFI द्वारा बूट निष्क्रिय)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="372"/>
         <source>Don&apos;t use fuseiso to mount iso files</source>
-        <translation type="unfinished"/>
+        <translation>आईएसओ फाइल माउंट करने हेतु fuseiso उपयोग न करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="398"/>
         <source>Size of ESP (uefi) partition:</source>
-        <translation type="unfinished"/>
+        <translation>ESP (uefi) विभाजन का आकार :</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="418"/>
         <source>Verbosity (less to more):</source>
-        <translation type="unfinished"/>
+        <translation>शाब्दिक उपयोग स्तर (कम से अधिक):</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="457"/>
         <source>vfat</source>
-        <translation type="unfinished"/>
+        <translation>vfat</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="462"/>
         <source>exfat</source>
-        <translation type="unfinished"/>
+        <translation>exfat</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="467"/>
@@ -166,53 +166,53 @@
     <message>
         <location filename="mainwindow.ui" line="472"/>
         <source>ntfs</source>
-        <translation type="unfinished"/>
+        <translation>ntfs</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="493"/>
         <source>Make separate data partition (percent)</source>
-        <translation type="unfinished"/>
+        <translation>डेटा विभाजन अलग से बनाएँ (प्रतिशत)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="500"/>
         <source>Format</source>
-        <translation type="unfinished"/>
+        <translation>प्रारूप</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="510"/>
         <source>Refresh drive list</source>
-        <translation type="unfinished"/>
+        <translation>ड्राइव सूची रिफ्रेश करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="524"/>
         <location filename="mainwindow.cpp" line="407"/>
         <source>Show advanced options</source>
-        <translation type="unfinished"/>
+        <translation>विस्तृत विकल्प दिखाएँ</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="544"/>
         <source>Mode</source>
-        <translation type="unfinished"/>
+        <translation>मोड</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="559"/>
         <source>Full-featured mode - writable LiveUSB</source>
-        <translation type="unfinished"/>
+        <translation>सर्व-सुविधा मोड - राइट योग्य यूएसबी</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="569"/>
         <source>Read-only, cannot be used with persistency</source>
-        <translation type="unfinished"/>
+        <translation>केवल रीड योग्य, सतत हेतु उपयोग संभव नहीं</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="572"/>
         <source>Image mode - read-only LiveUSB (dd)</source>
-        <translation type="unfinished"/>
+        <translation>इमेज मोड - केवल रीड योग्य लाइव यूएसबी (dd)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="586"/>
         <source>For distros other than antiX/MX use image mode (dd).</source>
-        <translation type="unfinished"/>
+        <translation>एंटी-एक्स व एमएक्स के अतिरिक्त सभी वितरणों हेतु इमेज मोड (dd) उपयोग करें।</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="634"/>
@@ -222,81 +222,83 @@
     <message>
         <location filename="mainwindow.ui" line="669"/>
         <source>Percent of USB-device to use:</source>
-        <translation type="unfinished"/>
+        <translation>यूएसबी उपकरण हेतु उपयोग प्रतिशत :</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="676"/>
         <source>Label ext partition:</source>
-        <translation type="unfinished"/>
+        <translation>Ext विभाजन हेतु उपनाम :</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="724"/>
         <source>Don&apos;t run commands that affect the usb device</source>
-        <translation type="unfinished"/>
+        <translation>यूएसबी उपकरण को प्रभावित करने वाली कमांड निष्पादित न करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="727"/>
         <source>Dry run (no change to system)</source>
-        <translation type="unfinished"/>
+        <translation>पूर्व परीक्षण (सिस्टम में कोई परिवर्तन नहीं)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="734"/>
         <source>clone from a mounted live-usb or iso-file.</source>
-        <translation type="unfinished"/>
+        <translation>माउंट हो रखी लाइव-यूएसबी या आईएसओ-फाइल से प्रतिरूपित करें।</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="737"/>
         <source>Clone an existing live system</source>
-        <translation type="unfinished"/>
+        <translation>मौजूदा लाइव सिस्टम प्रतिरूपित करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="744"/>
         <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
-        <translation type="unfinished"/>
+        <translation>एन्क्रिप्टेड विभाजन से ही बूट करें, प्रथम बूट पर कूटशब्द प्रमाणीकरण आवश्यक होगा</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="747"/>
         <source>Encrypt</source>
-        <translation type="unfinished"/>
+        <translation>एन्क्रिप्ट करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="754"/>
         <source>Clone running live system</source>
-        <translation type="unfinished"/>
+        <translation>कार्यरत लाइव सिस्टम प्रतिरूपित करें</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="86"/>
         <location filename="mainwindow.cpp" line="267"/>
         <location filename="mainwindow.cpp" line="392"/>
         <source>Failure</source>
-        <translation type="unfinished"/>
+        <translation>विफल</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="86"/>
         <source>Source and destination are on the same device, please select again.</source>
-        <translation type="unfinished"/>
+        <translation>स्रोत व लक्ष्य समान उपकरण पर हैं, कृपया पुनः चयन करें।</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="111"/>
         <source>Writing %1 using 'dd' command to /dev/%2,
 
 Please wait until the the process is completed</source>
-        <translation type="unfinished"/>
+        <translation>&apos;dd&apos; कमांड द्वारा %1 को /dev/%2 पर राइट करना जारी,
+
+कृपया प्रक्रिया पूर्ण होने तक प्रतीक्षा करें</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="265"/>
         <source>Success</source>
-        <translation>सफलता</translation>
+        <translation>सफल</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="265"/>
         <source>LiveUSB creation successful!</source>
-        <translation type="unfinished"/>
+        <translation>लाइव यूएसबी सृजन सफल!</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="267"/>
         <source>Error encountered in the LiveUSB creation process</source>
-        <translation type="unfinished"/>
+        <translation>लाइव यूएसबी सृजन प्रक्रिया में त्रुटि हुई</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="316"/>
@@ -306,18 +308,18 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="mainwindow.cpp" line="316"/>
         <source>Please select a USB device to write to</source>
-        <translation type="unfinished"/>
+        <translation>राइट हेतु यूएसबी उपकरण चुनें</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="319"/>
         <location filename="mainwindow.cpp" line="475"/>
         <source>clone</source>
-        <translation type="unfinished"/>
+        <translation>प्रतिरूप</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="355"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>%1 के बारे में</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="356"/>
@@ -327,55 +329,55 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="mainwindow.cpp" line="357"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
-        <translation type="unfinished"/>
+        <translation>आईएसओ फाइल, अन्य लाइव यूएसबी, लाइव सीडी/डीवीडी या कार्यरत लाइव सिस्टम से लाइव यूएसबी बनाने हेतु प्रोग्राम।</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="359"/>
         <source>Copyright (c) MX Linux</source>
-        <translation>प्रतिलिप्याधिकार (c) MX Linux</translation>
+        <translation>कॉपीराइट (c) एमएक्स लिनक्स</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="360"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>%1 लाइसेंस</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="368"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>%1 सहायता</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="379"/>
         <source>Select an ISO file to write to the USB drive</source>
-        <translation type="unfinished"/>
+        <translation>यूएसबी ड्राइव पर राइट करने हेतु आईएसओ फाइल चुनें</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="387"/>
         <location filename="mainwindow.cpp" line="458"/>
         <source>Select Source Directory</source>
-        <translation type="unfinished"/>
+        <translation>स्रोत डायरेक्टरी चुनें</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="392"/>
         <source>Could not find %1/antiX/linuxfs file</source>
-        <translation type="unfinished"/>
+        <translation>%1/antiX/linuxfs फाइल प्राप्ति विफल</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="413"/>
         <source>Hide advanced options</source>
-        <translation type="unfinished"/>
+        <translation>विस्तृत विकल्प अदृश्य करें</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="457"/>
         <location filename="mainwindow.cpp" line="473"/>
         <source>Select Source</source>
-        <translation type="unfinished"/>
+        <translation>स्रोत चयन</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="461"/>
         <location filename="mainwindow.cpp" line="479"/>
         <source>Select ISO file</source>
-        <translation type="unfinished"/>
+        <translation>आईएसओ फाइल चयन</translation>
     </message>
 </context>
 <context>
@@ -399,7 +401,7 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="about.cpp" line="51"/>
         <source>&amp;Close</source>
-        <translation>&amp;बंद करें</translation>
+        <translation>बंद करें (&amp;C)</translation>
     </message>
     <message>
         <location filename="main.cpp" line="75"/>
